Learn R Programming

HBV.IANIGLA (version 0.2.6)

lumped_hbv: Lumped HBV catchment data

Description

Here you will find what I consider the starting point dataset to begin the modeling with HBV.IANIGLA. This data is for modeling the streamflow of a synthetic basin with a perfect fit. For running the model you will have to connect the different package's modules (or functions) in order to get what I consider the most simple hydrological model.

Usage

lumped_hbv

Arguments

Format

A data frame containing:

Date

date series.

T(ºC)

air temperature series.

P(mm/d)

total ammount of precipitation per day.

PET(mm/d)

potential evapotranspiration series.

qout(mm/d)

specific basin discharge. This are the values that you have to reproduce.